@@ -1,4 +1,3 @@
-/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*
  * SPDX-FileCopyrightText: (C) 2020 Red Hat (www.redhat.com)
  * SPDX-License-Identifier: LGPL-2.1-or-later
@@ -2021,6 +2020,7 @@ ecb_m365_get_backend_property (ECalBackend *cal_backend,
 			E_CAL_STATIC_CAPABILITY_TASK_CAN_RECUR,
 			E_CAL_STATIC_CAPABILITY_TASK_HANDLE_RECUR,
 			E_CAL_STATIC_CAPABILITY_RETRACT_SUPPORTED,
+			E_CAL_STATIC_CAPABILITY_USER_IS_ORGANIZER_ONLY,
 			e_cal_meta_backend_get_capabilities (E_CAL_META_BACKEND (cbm365)),
 			NULL);
 	} else if (g_str_equal (prop_name, E_CAL_BACKEND_PROPERTY_CAL_EMAIL_ADDRESS)) {
