@@ -1,4 +1,3 @@
-/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*
  * SPDX-FileCopyrightText: (C) 2020 Red Hat (www.redhat.com)
  * SPDX-License-Identifier: LGPL-2.1-or-later
@@ -25,6 +24,7 @@ struct _CamelM365SettingsPrivate {
 	gchar *oauth2_tenant;
 	gchar *oauth2_client_id;
 	gchar *oauth2_redirect_uri;
+	gchar *oauth2_endpoint_host;
 };
 
 enum {
@@ -45,6 +45,7 @@ enum {
 	PROP_OAUTH2_TENANT,
 	PROP_OAUTH2_CLIENT_ID,
 	PROP_OAUTH2_REDIRECT_URI,
+	PROP_OAUTH2_ENDPOINT_HOST,
 	PROP_CONCURRENT_CONNECTIONS
 };
 
@@ -155,6 +156,12 @@ m365_settings_set_property (GObject *object,
 				g_value_get_string (value));
 			return;
 
+		case PROP_OAUTH2_ENDPOINT_HOST:
+			camel_m365_settings_set_oauth2_endpoint_host (
+				CAMEL_M365_SETTINGS (object),
+				g_value_get_string (value));
+			return;
+
 		case PROP_CONCURRENT_CONNECTIONS:
 			camel_m365_settings_set_concurrent_connections (
 				CAMEL_M365_SETTINGS (object),
@@ -284,6 +291,13 @@ m365_settings_get_property (GObject *object,
 				CAMEL_M365_SETTINGS (object)));
 			return;
 
+		case PROP_OAUTH2_ENDPOINT_HOST:
+			g_value_take_string (
+				value,
+				camel_m365_settings_dup_oauth2_endpoint_host (
+				CAMEL_M365_SETTINGS (object)));
+			return;
+
 		case PROP_CONCURRENT_CONNECTIONS:
 			g_value_set_uint (
 				value,
@@ -306,6 +320,7 @@ m365_settings_finalize (GObject *object)
 	g_free (m365_settings->priv->oauth2_tenant);
 	g_free (m365_settings->priv->oauth2_client_id);
 	g_free (m365_settings->priv->oauth2_redirect_uri);
+	g_free (m365_settings->priv->oauth2_endpoint_host);
 
 	/* Chain up to parent's method. */
 	G_OBJECT_CLASS (camel_m365_settings_parent_class)->finalize (object);
@@ -454,7 +469,7 @@ camel_m365_settings_class_init (CamelM365SettingsClass *class)
 			"oauth2-tenant",
 			"OAuth2 Tenant",
 			"OAuth2 Tenant to use, only if override-oauth2 is TRUE, otherwise the compile-time value is used",
-			NULL,
+			MICROSOFT365_TENANT,
 			G_PARAM_READWRITE |
 			G_PARAM_CONSTRUCT |
 			G_PARAM_STATIC_STRINGS));
@@ -466,7 +481,7 @@ camel_m365_settings_class_init (CamelM365SettingsClass *class)
 			"oauth2-client-id",
 			"OAuth2 Client ID",
 			"OAuth2 Client-ID to use, only if override-oauth2 is TRUE, otherwise the compile-time value is used",
-			NULL,
+			MICROSOFT365_CLIENT_ID,
 			G_PARAM_READWRITE |
 			G_PARAM_CONSTRUCT |
 			G_PARAM_STATIC_STRINGS));
@@ -478,7 +493,19 @@ camel_m365_settings_class_init (CamelM365SettingsClass *class)
 			"oauth2-redirect-uri",
 			"OAuth2 Redirect URI",
 			"OAuth2 Redirect URI to use, only if override-oauth2 is TRUE, otherwise the compile-time value is used",
-			NULL,
+			MICROSOFT365_REDIRECT_URI,
+			G_PARAM_READWRITE |
+			G_PARAM_CONSTRUCT |
+			G_PARAM_STATIC_STRINGS));
+
+	g_object_class_install_property (
+		object_class,
+		PROP_OAUTH2_ENDPOINT_HOST,
+		g_param_spec_string (
+			"oauth2-endpoint-host",
+			"OAuth2 Endpoint Host",
+			"OAuth2 endpoint host to use, only if override-oauth2 is TRUE, otherwise the compile-time value is used",
+			MICROSOFT365_ENDPOINT_HOST,
 			G_PARAM_READWRITE |
 			G_PARAM_CONSTRUCT |
 			G_PARAM_STATIC_STRINGS));
@@ -543,6 +570,22 @@ camel_m365_settings_get_from_backend (struct _EBackend *backend,
 	return CAMEL_M365_SETTINGS (settings);
 }
 
+void
+camel_m365_settings_lock (CamelM365Settings *settings)
+{
+	g_return_if_fail (CAMEL_IS_M365_SETTINGS (settings));
+
+	g_mutex_lock (&settings->priv->property_lock);
+}
+
+void
+camel_m365_settings_unlock (CamelM365Settings *settings)
+{
+	g_return_if_fail (CAMEL_IS_M365_SETTINGS (settings));
+
+	g_mutex_unlock (&settings->priv->property_lock);
+}
+
 gboolean
 camel_m365_settings_get_use_impersonation (CamelM365Settings *settings)
 {
@@ -581,12 +624,12 @@ camel_m365_settings_dup_impersonate_user (CamelM365Settings *settings)
 
 	g_return_val_if_fail (CAMEL_IS_M365_SETTINGS (settings), NULL);
 
-	g_mutex_lock (&settings->priv->property_lock);
+	camel_m365_settings_lock (settings);
 
 	protected = camel_m365_settings_get_impersonate_user (settings);
 	duplicate = g_strdup (protected);
 
-	g_mutex_unlock (&settings->priv->property_lock);
+	camel_m365_settings_unlock (settings);
 
 	return duplicate;
 }
@@ -597,17 +640,17 @@ camel_m365_settings_set_impersonate_user (CamelM365Settings *settings,
 {
 	g_return_if_fail (CAMEL_IS_M365_SETTINGS (settings));
 
-	g_mutex_lock (&settings->priv->property_lock);
+	camel_m365_settings_lock (settings);
 
 	if (g_strcmp0 (settings->priv->impersonate_user, impersonate_user) == 0) {
-		g_mutex_unlock (&settings->priv->property_lock);
+		camel_m365_settings_unlock (settings);
 		return;
 	}
 
 	g_free (settings->priv->impersonate_user);
 	settings->priv->impersonate_user = e_util_strdup_strip (impersonate_user);
 
-	g_mutex_unlock (&settings->priv->property_lock);
+	camel_m365_settings_unlock (settings);
 
 	g_object_notify (G_OBJECT (settings), "impersonate-user");
 }
@@ -650,12 +693,12 @@ camel_m365_settings_dup_email (CamelM365Settings *settings)
 
 	g_return_val_if_fail (CAMEL_IS_M365_SETTINGS (settings), NULL);
 
-	g_mutex_lock (&settings->priv->property_lock);
+	camel_m365_settings_lock (settings);
 
 	protected = camel_m365_settings_get_email (settings);
 	duplicate = g_strdup (protected);
 
-	g_mutex_unlock (&settings->priv->property_lock);
+	camel_m365_settings_unlock (settings);
 
 	return duplicate;
 }
@@ -666,17 +709,17 @@ camel_m365_settings_set_email (CamelM365Settings *settings,
 {
 	g_return_if_fail (CAMEL_IS_M365_SETTINGS (settings));
 
-	g_mutex_lock (&settings->priv->property_lock);
+	camel_m365_settings_lock (settings);
 
 	if (g_strcmp0 (settings->priv->email, email) == 0) {
-		g_mutex_unlock (&settings->priv->property_lock);
+		camel_m365_settings_unlock (settings);
 		return;
 	}
 
 	g_free (settings->priv->email);
 	settings->priv->email = e_util_strdup_strip (email);
 
-	g_mutex_unlock (&settings->priv->property_lock);
+	camel_m365_settings_unlock (settings);
 
 	g_object_notify (G_OBJECT (settings), "email");
 }
@@ -785,12 +828,12 @@ camel_m365_settings_dup_oauth2_tenant (CamelM365Settings *settings)
 
 	g_return_val_if_fail (CAMEL_IS_M365_SETTINGS (settings), NULL);
 
-	g_mutex_lock (&settings->priv->property_lock);
+	camel_m365_settings_lock (settings);
 
 	protected = camel_m365_settings_get_oauth2_tenant (settings);
 	duplicate = g_strdup (protected);
 
-	g_mutex_unlock (&settings->priv->property_lock);
+	camel_m365_settings_unlock (settings);
 
 	return duplicate;
 }
@@ -801,17 +844,17 @@ camel_m365_settings_set_oauth2_tenant (CamelM365Settings *settings,
 {
 	g_return_if_fail (CAMEL_IS_M365_SETTINGS (settings));
 
-	g_mutex_lock (&settings->priv->property_lock);
+	camel_m365_settings_lock (settings);
 
 	if (g_strcmp0 (settings->priv->oauth2_tenant, tenant) == 0) {
-		g_mutex_unlock (&settings->priv->property_lock);
+		camel_m365_settings_unlock (settings);
 		return;
 	}
 
 	g_free (settings->priv->oauth2_tenant);
 	settings->priv->oauth2_tenant = e_util_strdup_strip (tenant);
 
-	g_mutex_unlock (&settings->priv->property_lock);
+	camel_m365_settings_unlock (settings);
 
 	g_object_notify (G_OBJECT (settings), "oauth2-tenant");
 }
@@ -832,12 +875,12 @@ camel_m365_settings_dup_oauth2_client_id (CamelM365Settings *settings)
 
 	g_return_val_if_fail (CAMEL_IS_M365_SETTINGS (settings), NULL);
 
-	g_mutex_lock (&settings->priv->property_lock);
+	camel_m365_settings_lock (settings);
 
 	protected = camel_m365_settings_get_oauth2_client_id (settings);
 	duplicate = g_strdup (protected);
 
-	g_mutex_unlock (&settings->priv->property_lock);
+	camel_m365_settings_unlock (settings);
 
 	return duplicate;
 }
@@ -848,17 +891,17 @@ camel_m365_settings_set_oauth2_client_id (CamelM365Settings *settings,
 {
 	g_return_if_fail (CAMEL_IS_M365_SETTINGS (settings));
 
-	g_mutex_lock (&settings->priv->property_lock);
+	camel_m365_settings_lock (settings);
 
 	if (g_strcmp0 (settings->priv->oauth2_client_id, client_id) == 0) {
-		g_mutex_unlock (&settings->priv->property_lock);
+		camel_m365_settings_unlock (settings);
 		return;
 	}
 
 	g_free (settings->priv->oauth2_client_id);
 	settings->priv->oauth2_client_id = e_util_strdup_strip (client_id);
 
-	g_mutex_unlock (&settings->priv->property_lock);
+	camel_m365_settings_unlock (settings);
 
 	g_object_notify (G_OBJECT (settings), "oauth2-client-id");
 }
@@ -879,12 +922,12 @@ camel_m365_settings_dup_oauth2_redirect_uri (CamelM365Settings *settings)
 
 	g_return_val_if_fail (CAMEL_IS_M365_SETTINGS (settings), NULL);
 
-	g_mutex_lock (&settings->priv->property_lock);
+	camel_m365_settings_lock (settings);
 
 	protected = camel_m365_settings_get_oauth2_redirect_uri (settings);
 	duplicate = g_strdup (protected);
 
-	g_mutex_unlock (&settings->priv->property_lock);
+	camel_m365_settings_unlock (settings);
 
 	return duplicate;
 }
@@ -895,21 +938,68 @@ camel_m365_settings_set_oauth2_redirect_uri (CamelM365Settings *settings,
 {
 	g_return_if_fail (CAMEL_IS_M365_SETTINGS (settings));
 
-	g_mutex_lock (&settings->priv->property_lock);
+	camel_m365_settings_lock (settings);
 
 	if (g_strcmp0 (settings->priv->oauth2_redirect_uri, redirect_uri) == 0) {
-		g_mutex_unlock (&settings->priv->property_lock);
+		camel_m365_settings_unlock (settings);
 		return;
 	}
 
 	g_free (settings->priv->oauth2_redirect_uri);
 	settings->priv->oauth2_redirect_uri = e_util_strdup_strip (redirect_uri);
 
-	g_mutex_unlock (&settings->priv->property_lock);
+	camel_m365_settings_unlock (settings);
 
 	g_object_notify (G_OBJECT (settings), "oauth2-redirect-uri");
 }
 
+const gchar *
+camel_m365_settings_get_oauth2_endpoint_host (CamelM365Settings *settings)
+{
+	g_return_val_if_fail (CAMEL_IS_M365_SETTINGS (settings), NULL);
+
+	return settings->priv->oauth2_endpoint_host;
+}
+
+gchar *
+camel_m365_settings_dup_oauth2_endpoint_host (CamelM365Settings *settings)
+{
+	const gchar *protected;
+	gchar *duplicate;
+
+	g_return_val_if_fail (CAMEL_IS_M365_SETTINGS (settings), NULL);
+
+	camel_m365_settings_lock (settings);
+
+	protected = camel_m365_settings_get_oauth2_endpoint_host (settings);
+	duplicate = g_strdup (protected);
+
+	camel_m365_settings_unlock (settings);
+
+	return duplicate;
+}
+
+void
+camel_m365_settings_set_oauth2_endpoint_host (CamelM365Settings *settings,
+					      const gchar *endpoint_host)
+{
+	g_return_if_fail (CAMEL_IS_M365_SETTINGS (settings));
+
+	camel_m365_settings_lock (settings);
+
+	if (g_strcmp0 (settings->priv->oauth2_endpoint_host, endpoint_host) == 0) {
+		camel_m365_settings_unlock (settings);
+		return;
+	}
+
+	g_free (settings->priv->oauth2_endpoint_host);
+	settings->priv->oauth2_endpoint_host = e_util_strdup_strip (endpoint_host);
+
+	camel_m365_settings_unlock (settings);
+
+	g_object_notify (G_OBJECT (settings), "oauth2-endpoint-host");
+}
+
 guint
 camel_m365_settings_get_concurrent_connections (CamelM365Settings *settings)
 {
