@@ -1,4 +1,3 @@
-/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*
  * SPDX-FileCopyrightText: (C) 2020 Red Hat (www.redhat.com)
  * SPDX-License-Identifier: LGPL-2.1-or-later
@@ -20,6 +19,7 @@
 
 #define E_M365_ARTIFICIAL_FOLDER_ID_ORG_CONTACTS	"folder-id::orgContacts"
 #define E_M365_ARTIFICIAL_FOLDER_ID_USERS		"folder-id::users"
+#define E_M365_ARTIFICIAL_FOLDER_ID_PEOPLE		"folder-id::people"
 
 /* Currently, as of 2020-06-17, there is a limitation to 20 requests:
    https://docs.microsoft.com/en-us/graph/known-issues#json-batching */
@@ -442,6 +442,27 @@ gboolean	e_m365_connection_get_users_sync(EM365Connection *cnc,
 						 GPtrArray **out_contacts, /* EM365Contact * */
 						 GCancellable *cancellable,
 						 GError **error);
+gboolean	e_m365_connection_search_contacts_sync
+						(EM365Connection *cnc,
+						 const gchar *user_override, /* for which user, NULL to use the account user */
+						 EM365FolderKind kind,
+						 const gchar *folder_id,
+						 const gchar *search_text,
+						 GSList **out_contacts, /* transfer full, EM365Contact * */
+						 GCancellable *cancellable,
+						 GError **error);
+gboolean	e_m365_connection_get_people_accessible_sync
+						(EM365Connection *cnc,
+						 const gchar *user_override, /* for which user, NULL to use the account user */
+						 GCancellable *cancellable,
+						 GError **error);
+gboolean	e_m365_connection_get_people_sync
+						(EM365Connection *cnc,
+						 const gchar *user_override, /* for which user, NULL to use the account user */
+						 guint max_entries,
+						 GPtrArray **out_contacts, /* EM365Contact * */
+						 GCancellable *cancellable,
+						 GError **error);
 gboolean	e_m365_connection_list_calendar_groups_sync
 						(EM365Connection *cnc,
 						 const gchar *user_override, /* for which user, NULL to use the account user */
@@ -516,6 +537,49 @@ gboolean	e_m365_connection_delete_calendar_sync
 						 const gchar *calendar_id,
 						 GCancellable *cancellable,
 						 GError **error);
+gboolean	e_m365_connection_list_calendar_permissions_sync
+						(EM365Connection *cnc,
+						 const gchar *user_override, /* for which user, NULL to use the account user */
+						 const gchar *group_id, /* nullable - calendar group for group calendars */
+						 const gchar *calendar_id,
+						 GSList **out_permissions, /* EM365CalendarPermission * */
+						 GCancellable *cancellable,
+						 GError **error);
+gboolean	e_m365_connection_create_calendar_permission_sync
+						(EM365Connection *cnc,
+						 const gchar *user_override, /* for which user, NULL to use the account user */
+						 const gchar *group_id, /* nullable, then the default group is used */
+						 const gchar *calendar_id,
+						 JsonBuilder *permission,
+						 EM365CalendarPermission **out_created_permission,
+						 GCancellable *cancellable,
+						 GError **error);
+gboolean	e_m365_connection_get_calendar_permission_sync
+						(EM365Connection *cnc,
+						 const gchar *user_override, /* for which user, NULL to use the account user */
+						 const gchar *group_id, /* nullable, then the default group is used */
+						 const gchar *calendar_id,
+						 const gchar *permission_id,
+						 EM365CalendarPermission **out_permission,
+						 GCancellable *cancellable,
+						 GError **error);
+gboolean	e_m365_connection_update_calendar_permission_sync
+						(EM365Connection *cnc,
+						 const gchar *user_override, /* for which user, NULL to use the account user */
+						 const gchar *group_id, /* nullable - then the default group is used */
+						 const gchar *calendar_id,
+						 const gchar *permission_id,
+						 JsonBuilder *permission,
+						 GCancellable *cancellable,
+						 GError **error);
+gboolean	e_m365_connection_delete_calendar_permission_sync
+						(EM365Connection *cnc,
+						 const gchar *user_override, /* for which user, NULL to use the account user */
+						 const gchar *group_id, /* nullable - then the default group is used */
+						 const gchar *calendar_id,
+						 const gchar *permission_id,
+						 GCancellable *cancellable,
+						 GError **error);
 gboolean	e_m365_connection_list_events_sync
 						(EM365Connection *cnc,
 						 const gchar *user_override, /* for which user, NULL to use the account user */
