@@ -1,4 +1,3 @@
-/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*
  * SPDX-FileCopyrightText: (C) 2020 Red Hat (www.redhat.com)
  * SPDX-License-Identifier: LGPL-2.1-or-later
@@ -18,6 +17,7 @@ typedef enum {
 	E_M365_FOLDER_KIND_CONTACTS,
 	E_M365_FOLDER_KIND_ORG_CONTACTS,
 	E_M365_FOLDER_KIND_USERS,
+	E_M365_FOLDER_KIND_PEOPLE,
 	E_M365_FOLDER_KIND_SEARCH,
 	E_M365_FOLDER_KIND_TASKS,
 	E_M365_FOLDER_KIND_MEMOS
