@@ -1,4 +1,3 @@
-/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*
  * SPDX-FileCopyrightText: (C) 2020 Red Hat (www.redhat.com)
  * SPDX-License-Identifier: LGPL-2.1-or-later
@@ -17,6 +16,7 @@ G_BEGIN_DECLS
 #define EM365Attendee			JsonObject
 #define EM365Calendar			JsonObject
 #define EM365CalendarGroup		JsonObject
+#define EM365CalendarPermission		JsonObject
 #define EM365Category			JsonObject
 #define EM365ChecklistItem		JsonObject
 #define EM365Contact			JsonObject
@@ -44,9 +44,11 @@ G_BEGIN_DECLS
 #define EM365ResponseStatus		JsonObject
 #define EM365ScheduleInformation	JsonObject
 #define EM365ScheduleItem		JsonObject
+#define EM365ScoredEmailAddress		JsonObject
 #define EM365Task			JsonObject
 #define EM365TaskList			JsonObject
 #define EM365TimeOfDay			gint64
+#define EM365Website			JsonObject
 #define EM365WorkingHours		JsonObject
 
 #define E_M365_RECURRENCE_BLOB_NAME "Binary {00062002-0000-0000-c000-000000000046} Id 0x8216"
@@ -84,6 +86,19 @@ typedef enum _EM365CalendarColorType {
 	E_M365_CALENDAR_COLOR_MAX_COLOR		= 9
 } EM365CalendarColorType;
 
+typedef enum _EM365CalendarPermissionType {
+	E_M365_CALENDAR_PERMISSION_NOT_SET				 = -1,
+	E_M365_CALENDAR_PERMISSION_UNKNOWN				 = 0,
+	E_M365_CALENDAR_PERMISSION_NONE					 = 1 << 0,
+	E_M365_CALENDAR_PERMISSION_FREE_BUSY_READ			 = 1 << 1,
+	E_M365_CALENDAR_PERMISSION_LIMITED_READ				 = 1 << 2,
+	E_M365_CALENDAR_PERMISSION_READ					 = 1 << 3,
+	E_M365_CALENDAR_PERMISSION_WRITE				 = 1 << 4,
+	E_M365_CALENDAR_PERMISSION_DELEGATE_WITHOUT_PRIVATE_EVENT_ACCESS = 1 << 5,
+	E_M365_CALENDAR_PERMISSION_DELEGATE_WITH_PRIVATE_EVENT_ACCESS	 = 1 << 6,
+	E_M365_CALENDAR_PERMISSION_CUSTOM				 = 1 << 7
+} EM365CalendarPermissionType;
+
 typedef enum _EM365DayOfWeekType {
 	E_M365_DAY_OF_WEEK_NOT_SET,
 	E_M365_DAY_OF_WEEK_UNKNOWN,
@@ -251,6 +266,16 @@ typedef enum _EM365TaskListKind {
 	E_M365_TASK_LIST_KIND_UNKNOWN_FUTURE_VALUE
 } EM365TaskListKind;
 
+typedef enum _EM365WebsiteType {
+	E_M365_WEBSITE_TYPE_NOT_SET,
+	E_M365_WEBSITE_TYPE_UNKNOWN,
+	E_M365_WEBSITE_TYPE_OTHER,
+	E_M365_WEBSITE_TYPE_HOME,
+	E_M365_WEBSITE_TYPE_WORK,
+	E_M365_WEBSITE_TYPE_BLOG,
+	E_M365_WEBSITE_TYPE_PROFILE
+} EM365WebsiteType;
+
 const gchar *	e_m365_calendar_color_to_rgb		(EM365CalendarColorType color);
 EM365CalendarColorType
 		e_m365_rgb_to_calendar_color		(const gchar *rgb);
@@ -702,6 +727,29 @@ JsonArray *	e_m365_contact_user_get_proxy_addresses	(EM365Contact *contact); /*
 const gchar *	e_m365_contact_user_get_state		(EM365Contact *contact);
 const gchar *	e_m365_contact_user_get_street_address	(EM365Contact *contact);
 
+const gchar *	e_m365_contact_person_get_im_address	(EM365Contact *contact);
+gboolean	e_m365_contact_person_get_is_favorite	(EM365Contact *contact);
+const gchar *	e_m365_contact_person_get_type_class	(EM365Contact *contact);
+const gchar *	e_m365_contact_person_get_type_subclass	(EM365Contact *contact);
+JsonArray *	e_m365_contact_person_get_phones	(EM365Contact *contact); /* EM365Phone * */
+JsonArray *	e_m365_contact_person_get_postal_addresses			 /* EM365Location * */
+							(EM365Contact *contact);
+JsonArray *	e_m365_contact_person_get_scored_email_addresses		 /* EM365ScoredEmailAddress * */
+							(EM365Contact *contact);
+const gchar *	e_m365_contact_person_get_user_principal_name
+							(EM365Contact *contact);
+JsonArray *	e_m365_contact_person_get_websites	(EM365Contact *contact); /* EM365Website * */
+const gchar *	e_m365_contact_person_get_yomi_company	(EM365Contact *contact);
+
+const gchar *	e_m365_scored_email_address_get_address	(EM365ScoredEmailAddress *scored_email_address);
+gdouble		e_m365_scored_email_address_get_relevance_score
+							(EM365ScoredEmailAddress *scored_email_address);
+
+const gchar *	e_m365_website_get_address		(EM365Website *website);
+const gchar *	e_m365_website_get_display_name		(EM365Website *website);
+EM365WebsiteType
+		e_m365_website_get_type			(EM365Website *website);
+
 const gchar *	e_m365_calendar_group_get_id		(EM365CalendarGroup *group);
 const gchar *	e_m365_calendar_group_get_change_key	(EM365CalendarGroup *group);
 const gchar *	e_m365_calendar_group_get_class_id	(EM365CalendarGroup *group);
@@ -737,6 +785,31 @@ EM365OnlineMeetingProviderType
 void		e_m365_calendar_add_default_online_meeting_provider
 							(JsonBuilder *builder,
 							 EM365OnlineMeetingProviderType provider);
+guint32		e_m365_calendar_permission_get_allowed_roles /* bit-or of EM365CalendarPermissionType */
+							(EM365CalendarPermission *permission);
+EM365EmailAddress *
+		e_m365_calendar_permission_get_email_address
+							(EM365CalendarPermission *permission);
+void		e_m365_calendar_permission_add_email_address
+							(JsonBuilder *builder,
+							 const gchar *name,
+							 const gchar *address);
+const gchar *	e_m365_calendar_permission_get_id	(EM365CalendarPermission *permission);
+gboolean	e_m365_calendar_permission_get_is_inside_organization
+							(EM365CalendarPermission *permission);
+void		e_m365_calendar_permission_add_is_inside_organization
+							(JsonBuilder *builder,
+							 gboolean value);
+gboolean	e_m365_calendar_permission_get_is_removable
+							(EM365CalendarPermission *permission);
+void		e_m365_calendar_permission_add_is_removable
+							(JsonBuilder *builder,
+							 gboolean value);
+EM365CalendarPermissionType
+		e_m365_calendar_permission_get_role	(EM365CalendarPermission *permission);
+void		e_m365_calendar_permission_add_role
+							(JsonBuilder *builder,
+							 EM365CalendarPermissionType value);
 EM365ResponseType
 		e_m365_response_status_get_response	(EM365ResponseStatus *response_status);
 time_t		e_m365_response_status_get_time		(EM365ResponseStatus *response_status);
