@@ -1,4 +1,3 @@
-/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*
  * SPDX-FileCopyrightText: (C) 2024 Red Hat (www.redhat.com>
  * SPDX-License-Identifier: LGPL-2.1-or-later
@@ -25,6 +24,7 @@ ICalTimezone *	e_ews_common_utils_get_configured_icaltimezone	(void);
 ICalProperty *	e_ews_common_utils_find_attendee		(ECalBackend *cal_backend,
 								 ICalComponent *icomp,
 								 GHashTable *aliases);
+gboolean	e_ews_common_utils_gsettings_schema_exists	(const gchar *schema_id);
 
 G_END_DECLS
 
